/**
 * This file is part of the swagger-jsdoc-express distribution.
 * Copyright (c) e.GO Digital GmbH, Aachen, Germany (https://www.e-go-digital.com/)
 *
 * swagger-jsdoc-express is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation, version 3.
 *
 * swagger-jsdoc-express is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
import { SwaggerV2DocBlock } from './parse';
/**
 * Possible value for an API url scheme.
 */
export declare type ApiUrlScheme = 'http' | 'https';
/**
 * Options for 'generateSwaggerV2Doc()' function.
 */
export interface GenerateSwaggerV2DocumentOptions {
    /**
     * The base path of the API.
     */
    'basePath'?: string;
    /**
     * External docs.
     */
    'externalDocs'?: SwaggerV2DocumentExternalDocs;
    /**
     * The host name.
     */
    'host'?: string;
    /**
     * Information about the document.
     */
    'info'?: SwaggerV2DocumentInfo;
    /**
     * The list of possible schemes.
     */
    'schemes'?: ApiUrlScheme | ApiUrlScheme[];
    /**
     * Security definitions.
     */
    'securityDefinitions'?: SwaggerV2SecurityDefintionList;
    /**
     * List of tags (key => name; value => description).
     */
    'tags'?: {
        [name: string]: string;
    };
}
/**
 * List of Swagger 2 definitions.
 */
export declare type SwaggerV2DocDefinitionList = {
    [key: string]: any;
};
/**
 * A Swagger 2 document.
 */
export interface SwaggerV2Document {
    /**
     * The header.
     */
    'swagger': '2.0';
    /**
     * Information about the document.
     */
    'info'?: SwaggerV2DocumentInfo;
    /**
     * The host name.
     */
    'host'?: string;
    /**
     * List of tags.
     */
    'tags'?: SwaggerV2DocumentTag[];
    /**
     * The list of possible schemes.
     */
    'schemes'?: ApiUrlScheme[];
    /**
     * The list of paths.
     */
    'paths'?: SwaggerV2DocumentPathList;
    /**
     * The list of definitions.
     */
    'definitions'?: SwaggerV2DocDefinitionList;
    /**
     * External docs.
     */
    'externalDocs'?: SwaggerV2DocumentExternalDocs;
    /**
     * The base path of the API.
     */
    'basePath'?: string;
    /**
     * Security definitions.
     */
    'securityDefinitions'?: SwaggerV2SecurityDefintionList;
}
/**
 * Information of a Swagger 2 document.
 */
export interface SwaggerV2DocumentInfo {
    /**
     * Contact information.
     */
    'contact'?: SwaggerV2DocumentInfoContact;
    /**
     * API description.
     */
    'description'?: string;
    /**
     * License information.
     */
    'license'?: SwaggerV2DocumentInfoLicense;
    /**
     * Version.
     */
    'version'?: string;
    /**
     * The title.
     */
    'title'?: string;
}
/**
 * Contact information in the 'info' block of a Swagger 2 document.
 */
export interface SwaggerV2DocumentInfoContact {
    /**
     * The email address.
     */
    'email'?: string;
    /**
     * The display name of the contact.
     */
    'name'?: string;
    /**
     * The URL.
     */
    'url'?: string;
}
/**
 * License information in the 'info' block of a Swagger 2 document.
 */
export interface SwaggerV2DocumentInfoLicense {
    /**
     * The display name of the license.
     */
    'name'?: string;
    /**
     * The URL.
     */
    'url'?: string;
}
/**
 * Swagger V2 external documentation information.
 */
export interface SwaggerV2DocumentExternalDocs {
    /**
     * A description.
     */
    'description'?: string;
    /**
     * The URL to the documentation.
     */
    'url'?: string;
}
/**
 * List of Swagger 2 paths.
 */
export declare type SwaggerV2DocumentPathList = {
    [key: string]: any;
};
/**
 * A Swagger 2 tag.
 */
export declare type SwaggerV2DocumentTag = {
    /**
     * The description.
     */
    'description'?: string;
    /**
     * The name.
     */
    'name'?: string;
};
/**
 * Data for a Swagger V2 security defintion.
 */
export declare type SwaggerV2SecurityDefintion = {
    [key: string]: any;
};
/**
 * Swagger V2 security defintions.
 */
export declare type SwaggerV2SecurityDefintionList = {
    [name: string]: SwaggerV2SecurityDefintion;
};
/**
 * Generates a Swagger V2 document.
 *
 * @param {SwaggerV2DocBlock|SwaggerV2DocBlock[]} blocks One or more blocks.
 * @param {GenerateSwaggerV2DocumentOptions} [opts] Custom, optional options.
 *
 * @return {SwaggerV2Document} The generated document.
 */
export declare function generateSwaggerV2Document(blocks: SwaggerV2DocBlock | SwaggerV2DocBlock[], opts?: GenerateSwaggerV2DocumentOptions): SwaggerV2Document;
